# OpenID Connect Authorization Code grant type support for OpenStack clients

This package is not maintained anymore, please use the
[keystoneauth-oidc](https://pypi.python.org/pypi/keystoneauth-oidc/) package
instead.
